"""
.. currentmodule:: flytekitplugins.onnxpytorch

.. autosummary::
   :template: custom.rst
   :toctree: generated/

   PyTorch2ONNXConfig
   PyTorch2ONNX
"""

from .schema import PyTorch2ONNX, PyTorch2ONNXConfig
